This package contains helper functions for Gaussian and Binomial distributions.

Helper functions to find mean, find standard deviation, find pdf, plot distribution, 
add separate Gaussian/ Binomial distributions and plot them.